@@ -42,6 +42,7 @@
 
 #include <QApplication>
 #include <QClipboard>
+#include <QCryptographicHash>
 #include <QDateTime>
 #include <QDir>
 #include <QFile>
@@ -512,6 +513,13 @@ QStringList monitorFormatsToSave(const Commands &&automaticCommands)
     return formats;
 }
 
+QScriptValue checksumForArgument(Scriptable *scriptable, QCryptographicHash::Algorithm method)
+{
+    const auto data = scriptable->makeByteArray(scriptable->argument(0));
+    const QByteArray hash = QCryptographicHash::hash(data, method).toHex();
+    return QString::fromUtf8(hash);
+}
+
 } // namespace
 
 Scriptable::Scriptable(
@@ -1841,6 +1849,26 @@ QScriptValue Scriptable::fromBase64()
     return newByteArray(QByteArray::fromBase64(makeByteArray(argument(0))));
 }
 
+QScriptValue Scriptable::md5sum()
+{
+    return checksumForArgument(this, QCryptographicHash::Md5);
+}
+
+QScriptValue Scriptable::sha1sum()
+{
+    return checksumForArgument(this, QCryptographicHash::Sha1);
+}
+
+QScriptValue Scriptable::sha256sum()
+{
+    return checksumForArgument(this, QCryptographicHash::Sha256);
+}
+
+QScriptValue Scriptable::sha512sum()
+{
+    return checksumForArgument(this, QCryptographicHash::Sha512);
+}
+
 QScriptValue Scriptable::open()
 {
     m_skipArguments = -1;
